#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

A script to export some graphs in SVG format for inclusion in the README
and showcasing.

Typically you would run this file from a command line like this:

     ipython3 -i -- ~/deploy/waste_flow/scripts/docs/export_showcase_svg.py
"""

# Built-in modules #

# Internal modules #
from waste_flow import repos_dir

# First party modules #

# Third party modules #
from tqdm import tqdm

###############################################################################
# Legend #
from waste_flow.viz.gen_by_country import legend

# Set it to SVG #
legend.formats = ('svg',)

# Change output path #
legend.base_dir = repos_dir + 'docs/showcase_graphs/'

# Plot #
legend.plot(rerun=True)

###############################################################################
# Sectors #
from waste_flow.viz.gen_by_sector import sectors

# Select a given nace category #
viz = sectors['C20-C22']

# Set them all to SVG #
for g in viz.all_graphs: g.formats = ('svg',)

# Change output paths #
for g in viz.all_graphs: g.base_dir = repos_dir + 'docs/showcase_graphs/'

# Change names #
for g in viz.all_graphs: g.short_name = '_'.join(c for c in g.batch)

# Plot all graphs #
for g in tqdm(viz.all_graphs): g.plot(rerun=True)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

Script to generate the output PDF comparison report.

Typically you would run this file from a command line like this:

     ipython3 -i -- ~/deploy/waste_flow/scripts/outputs/make_pdf_report.py
"""

###############################################################################
from waste_flow.viz.gen_by_country import legend
print(legend.plot(rerun=True))

from waste_flow.viz.gen_by_country import countries
for gen_viz in countries.values():
    print(gen_viz.plot(rerun=True))

from waste_flow.viz.gen_by_sector import sectors
for gen_viz in sectors.values():
    print(gen_viz.plot(rerun=True))

#-----------------------------------------------------------------------------#
from waste_flow.viz.summary import legend_ind, legend_hh
print(legend_ind.plot(rerun=True))
print(legend_hh.plot(rerun=True))

from waste_flow.viz.summary import countries_ind, countries_hh
for gen_viz in countries_ind.values():
    print(gen_viz.plot(rerun=True))
for gen_viz in countries_hh.values():
    print(gen_viz.plot(rerun=True))

#-----------------------------------------------------------------------------#
from waste_flow.reports.comparison import report
print(report())



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

Development script to test the usage examples included in the README.

Typically you would run this file from a command line like this:

     ipython3 -i -- ~/deploy/waste_flow/scripts/docs/run_readme_examples.py
"""

###############################################################################
from waste_flow.analysis import waste_ana
print(waste_ana.dry_mass)

###############################################################################
from waste_flow.generation import waste_gen
params = ("waste   == 'W073' & "
          "country == 'UK' & "
          "year    == '2008'")
result = waste_gen.long_format.query(params)
print(result)

###############################################################################
from waste_flow.viz.gen_by_country import legend
print(legend.plot(rerun=True))
from waste_flow.viz.gen_by_country import countries
for gen_viz in countries.values():
    print(gen_viz.plot(rerun=True))



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

Development script to test some of the methods in `waste_flow`.
This is mostly just scrap code. Some of these snippets could be used
as extra examples in the main `README.md` file.
"""

###############################################################################
from waste_flow.zip_files import waste_gen, waste_trt

print(waste_gen.cache_is_valid)
print(waste_trt.cache_is_valid)

print(waste_gen.refresh_cache())
print(waste_trt.refresh_cache())

print(waste_gen.raw_csv)
print(waste_trt.raw_csv)

del waste_gen.processed_csv
del waste_trt.processed_csv

print(waste_gen.processed_csv.shape)
print(waste_trt.processed_csv.shape)

print(waste_gen.df)
print(waste_trt.df)

###############################################################################
from waste_flow.viz.gen_by_country import legend
print(legend.plot(rerun=True))

from waste_flow.viz.gen_by_sector import sectors as all_gen_viz

i = 0
for gen_viz in all_gen_viz.values():
    print(gen_viz.plot(rerun=True))
    i += 1
    if i > 3: break

###############################################################################
from waste_flow.reports.comparison import ComparisonReport
report = ComparisonReport('~/test/report.pdf')
print(report())

###############################################################################
from waste_flow.viz.gen_by_sector import sectors as all_gen_viz
print(all_gen_viz)
print(list(all_gen_viz.values())[0].df.index.levels[0])

###############################################################################
from waste_flow.common import wastes_selected
from waste_flow.common import nace_selected
print(wastes_selected)
print(nace_selected)

###############################################################################
from waste_flow.spreading import spread
print(spread.by_nace['A'])
print(spread.by_nace['EP_HH'])

###############################################################################
from waste_flow.generation import waste_gen
del waste_gen.spread_waste
print(waste_gen.dry_mass)

###############################################################################
from waste_flow.analysis import waste_ana
del waste_ana.spread_waste
print(waste_ana.spread_waste)

###############################################################################
from waste_flow.analysis import waste_ana
print(waste_ana.summary_recovered)

###############################################################################
from waste_flow.country import countries
eu = countries['EU28']
df = eu.wide_format

###############################################################################
from waste_flow.viz.summary import countries_ind
for gen_viz in countries_ind.values(): print(gen_viz.plot(rerun=True))

###############################################################################
from waste_flow.generation import waste_gen
params = "country == 'BA'"
result = waste_gen.long_format.query(params)
print(result)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

Script to convert the extra data excel files into their CSV equivalents.

Typically you would run this file from a command line like this:

     ipython3 -i -- ~/deploy/waste_flow/scripts/extra_data/convert_all_xls_to_csv.py
"""

# Built-in modules #

# First party modules #
from plumbing.xls_tables import ConvertExcelToCSV

# Third party modules #

# Internal modules #
from waste_flow import module_dir

###############################################################################
# Constants #
convert_pairs = (
    ('extra_data_xls/nace_to_full_name.xlsx',      'extra_data_csv/'),
    ('extra_data_xls/waste_to_full_name.xlsx',     'extra_data_csv/'),
    ('extra_data_xls/treatment_to_full_name.xlsx', 'extra_data_csv/'),
    ('extra_data_xls/waste_spreading.xlsx',        'extra_data_csv/')
)

if __name__ == '__main__':
    for pair in convert_pairs:
        source, dest = module_dir + pair[0], module_dir + pair[1]
        converter = ConvertExcelToCSV(source, dest, index=False)
        converter()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.

Script to generate the output XLS files.

Typically you would run this file from a command line like this:

     ipython3 -i -- ~/deploy/waste_flow/scripts/outputs/make_xls_outputs.py
"""

###############################################################################
from waste_flow.analysis import waste_ana
del waste_ana.spread_waste

from waste_flow.outputs import waste_breakdown, summary_recovered
waste_breakdown()
summary_recovered()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Written by Lucas Sinclair.

JRC Biomass Project.
Unit D1 Bioeconomy.
"""

# Built-in modules #
import os, socket

# Internal modules #
import waste_flow
from waste_flow.country import all_codes

# First party modules #
from pymarktex.templates import Template
from plumbing.common     import pretty_now

###############################################################################
class ReportTemplate(Template):
    """Things that are common to most reports in waste_flow."""

    def project_name(self):      return waste_flow.project_name
    def project_url(self):       return waste_flow.project_url
    def project_version(self):   return waste_flow.__version__
    def now(self):               return pretty_now()

    def hostname(self):
        host = os.environ.get('WASTE_FLOW_HOSTNAME')
        if host is not None: return host
        return socket.gethostname()

    def git(self):
        if not waste_flow.git_repo: return False
        return {'git_hash'  : waste_flow.git_repo.hash}

    def country_list(self):
        aggregates = ['EU27_2020', 'EU28']
        countries  = [c for c in all_codes if c not in aggregates]
        msg = "%s as well as %s which represent aggregates."
        return msg % (', '.join(countries), ', '.join(aggregates))


#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Imports #
from setuptools import setup, find_namespace_packages
from os import path

# Load the contents of the README.md file #
this_dir = path.abspath(path.dirname(__file__))
readme_path = path.join(this_dir, 'README.md')
with open(readme_path, encoding='utf-8') as handle: readme = handle.read()

# Call setup #
setup(
    name             = 'waste_flow',
    version          = '1.3.2',
    description      = 'A package for retrieving data concerning waste '
                       'management on the European continent.',
    license          = 'MIT',
    url              = 'http://github.com/xapple/waste_flow/',
    author           = 'Lucas Sinclair',
    author_email     = 'lucas.sinclair@me.com',
    packages         = find_namespace_packages(),
    install_requires = ['autopaths>=1.4.12', 'plumbing>=2.10.0',
                        'pymarktex>=1.4.6', 'pandas', 'numpy',
                        'pytest', 'requests', 'matplotlib'],
    python_requires  = ">=3.6",
    long_description = readme,
    long_description_content_type = 'text/markdown',
    include_package_data = True,
)